==> spring-cloud-contract-shade-3.1.3-sources.jar: shaded/org/apache/maven/repository/internal/VersionsMetadataGeneratorFactory.java <==
package shaded.shaded.org.apache.maven.repository.internal;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import javax.inject.Named;
import javax.inject.Singleton;

import org.eclipse.aether.RepositorySystemSession;
import org.eclipse.aether.deployment.DeployRequest;
import shaded.shaded.org.eclipse.aether.impl.MetadataGenerator;
import shaded.shaded.org.eclipse.aether.impl.MetadataGeneratorFactory;
import org.eclipse.aether.installation.InstallRequest;

/**
 * @author Benjamin Bentmann
 */
@Named( "versions" )
@Singleton
public class VersionsMetadataGeneratorFactory
    implements MetadataGeneratorFactory
{

    public MetadataGenerator newInstance( RepositorySystemSession session, InstallRequest request )
    {
        return new VersionsMetadataGenerator( session, request );
    }

    public MetadataGenerator newInstance( RepositorySystemSession session, DeployRequest request )
    {
        return new VersionsMetadataGenerator( session, request );
    }

    public float getPriority()
    {
        return 5;
    }

}

==> spring-cloud-contract-shade-4.1.2-sources.jar: shaded/org/apache/maven/repository/internal/VersionsMetadataGeneratorFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package shaded.shaded.org.apache.maven.repository.internal;

import javax.inject.Named;
import javax.inject.Singleton;

import org.eclipse.aether.RepositorySystemSession;
import org.eclipse.aether.deployment.DeployRequest;
import shaded.shaded.org.eclipse.aether.impl.MetadataGenerator;
import shaded.shaded.org.eclipse.aether.impl.MetadataGeneratorFactory;
import org.eclipse.aether.installation.InstallRequest;

/**
 * Maven GA level metadata generator factory.
 */
@Named("versions")
@Singleton
public class VersionsMetadataGeneratorFactory implements MetadataGeneratorFactory {
    @Override
    public MetadataGenerator newInstance(RepositorySystemSession session, InstallRequest request) {
        return new VersionsMetadataGenerator(session, request);
    }

    @Override
    public MetadataGenerator newInstance(RepositorySystemSession session, DeployRequest request) {
        return new VersionsMetadataGenerator(session, request);
    }

    @SuppressWarnings("checkstyle:magicnumber")
    @Override
    public float getPriority() {
        return 20; // GA level metadata should be deployed 2nd MD
    }
}
